from app.scripts import BaseMigrationScript

import os
import app.util
import shutil

class MigrationScript(BaseMigrationScript):

    scriptDescription = "Migrate EventQ Database to setup the data location"

    def migrate(self):

        # Due to Data file location change
        self.relocateDataFiles()

    def createFolderIfNotExisting(self, folder):
        if not os.path.exists(folder):
            try:
                os.makedirs(folder)
            except:
                self.logMesg("warn", "Creating folder %s failed" % folder)


    def relocateDataFiles(self):
        old_mongodb_data_dir = '/opt/collabnet/mongodb'
        new_mongodb_data_dir = self.cfg['MONGODB_DATA_DIR']
        mongodb_home_dir = '/var/lib/mongo'

        if os.path.isdir(old_mongodb_data_dir):
            if os.path.isdir(new_mongodb_data_dir):
              os.rename(new_mongodb_data_dir, "%s.bak" % (new_mongodb_data_dir))

            # copy credential file to new location
            mongodb_credential_file = os.path.join(old_mongodb_data_dir, '.mongo_passwords')
            if os.path.isfile(mongodb_credential_file):
                shutil.copy(mongodb_credential_file, mongodb_home_dir)

            # copy data files to new location
            old_data_path = os.path.join(old_mongodb_data_dir, 'data')
            if os.path.isdir(old_data_path):
                shutil.move(old_data_path, new_mongodb_data_dir)

            # Delete (or unlink) the old data
            if os.path.islink(old_mongodb_data_dir):
                self.logMesg("info", "Old MongoDB dir %s is a symlink; unlinking" % old_mongodb_data_dir)
                self.logMesg("info", "Leaving symlink target %s untouched" % os.path.realpath(old_mongodb_data_dir))
                os.unlink(old_mongodb_data_dir)
            else:
                self.logMesg("info", "Removing old MongoDB dir %s" % old_mongodb_data_dir)
                shutil.rmtree(old_mongodb_data_dir)

        self.createFolderIfNotExisting(new_mongodb_data_dir)

        app.util.runSystem("chown -R %s:%s %s" % (self.cfg['MONGODB_USER'], self.cfg['MONGODB_GROUP'], new_mongodb_data_dir), self.log)